# Golmorich - A Simple Text Editor
## Version: 1.2

A simple text editor with the following features:
- Open, save and save as options
- If a file is new, save option works as save as
- Identifies the following file types: C, C Header, C++, Python, Text
- Package used: Tkinter, os

Inspiration from [Zack King's Tutorial](https://www.youtube.com/watch?v=xqDonHEYPgA).

### Installation Instruction:
`pip install Golmorich`

### Running:
In terminal, type the following command: `golmorich.py`

### Screenshot:
![Golmorich Screenshot](https://pbs.twimg.com/media/EDOJxKvVUAAlgTw?format=jpg&name=large)